@@ -239,7 +239,8 @@ class NXSCreateOnlineCPFS2Test(
                      'from nxstools.pyeval import common\n'
                      'common.blockitem_rm(commonblock, '
                      '["myeigerdectris_stepindex""])\n'
-                     'ds.result = ds.myeigerdectris_description</result>\n'
+                     'ds.result = ds.myeigerdectris_description\n'
+                     '</result>\n'
                      '  $datasources.myeigerdectris_description\n'
                      '  </datasource>\n'
                      '</definition>\n',
@@ -359,8 +360,8 @@ class NXSCreateOnlineCPFS2Test(
                      'name="myeigerdectris_stepindex">\n'
                      '    <result name="result">\n'
                      'from nxstools.pyeval import common\n'
-                     'ds.result = common.blockitem_addint(\n'
-                     '    commonblock, "myeigerdectris_stepindex", '
+                     'ds.result = common.blockitem_addint('
+                     'commonblock, "myeigerdectris_stepindex", '
                      'ds.myeigerdectris_nbimages)\n'
                      'ds.result = len(commonblock['
                      '"myeigerdectris_stepindex"])\n'
@@ -385,20 +386,20 @@ class NXSCreateOnlineCPFS2Test(
                      'name="myeigerdectris_triggermode_cb">\n'
                      '    <result name="result">\n'
                      'from nxstools.pyeval import eigerdectris\n'
-                     'ds.result = eigerdectris.triggermode_cb(\n'
-                     '    commonblock,\n'
-                     '    "myeigerdectris",\n'
-                     '    ds.myeigerdectris_triggermode,\n'
-                     '    ds.myeigerdectris_nbimages,\n'
-                     '    "haso000:10000",\n'
-                     '    "p09/eigerdectris/exp.01",\n'
-                     '    "$var.filename",\n'
-                     '    "myeigerdectris_stepindex",\n'
-                     '    "$var.entryname#\'scan\'$var.serialno",\n'
-                     '    "instrument",\n'
-                     '    "EigerDectris",\n'
-                     '    "EigerFilewriter"\n'
-                     '    )\n'
+                     'ds.result = eigerdectris.triggermode_cb('
+                     'commonblock,'
+                     ' "myeigerdectris",'
+                     ' ds.myeigerdectris_triggermode,'
+                     ' ds.myeigerdectris_nbimages,'
+                     ' "haso000:10000",'
+                     ' "p09/eigerdectris/exp.01",'
+                     ' "$var.filename",'
+                     ' "myeigerdectris_stepindex",'
+                     ' "$var.entryname#\'scan\'$var.serialno",'
+                     ' "instrument",'
+                     ' "EigerDectris",'
+                     ' "EigerFilewriter"'
+                     ')\n'
                      '    </result>\n'
                      '    $datasources.myeigerdectris_triggermode\n'
                      '    $datasources.myeigerdectris_nbimages\n'
